==> test-engine-10.3.18-sources.jar: com/xebialabs/deployit/test/task/ControlTaskTester.java <==
package com.xebialabs.deployit.test.task;

import java.util.List;

import com.xebialabs.deployit.plugin.api.flow.Step;
import com.xebialabs.deployit.plugin.api.flow.StepExitCode;
import com.xebialabs.deployit.plugin.api.reflect.MethodDescriptor;
import com.xebialabs.deployit.plugin.api.services.Repository;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.deployit.plugin.api.udm.Parameters;
import com.xebialabs.deployit.test.deployment.DeployitTester;
import com.xebialabs.deployit.test.repository.InMemoryRepository;
import com.xebialabs.deployit.test.support.TestExecutionContext;

import static com.google.common.base.Preconditions.checkNotNull;

public class ControlTaskTester {

    private final Repository repository;

    public ControlTaskTester() {
        this(new InMemoryRepository());
    }

    public ControlTaskTester(Repository repository) {
        this.repository = repository;
    }

    /**
     * Executes all steps of non-parametrized control task on CI
     */
    @SuppressWarnings("unchecked")
    public StepExitCode executeControlTask(ConfigurationItem ci, String task) {
        MethodDescriptor controlTask = checkNotNull(ci.getType().getDescriptor().getControlTask(task));
        return executePlan((List<Step>)controlTask.invoke(ci));
    }

    /**
     * Executes all steps of parametrized control task on CI
     */
    @SuppressWarnings("unchecked")
    public StepExitCode executeControlTask(ConfigurationItem ci, String task, Parameters parameters) {
        MethodDescriptor controlTask = checkNotNull(ci.getType().getDescriptor().getControlTask(task));
        return executePlan((List<Step>) controlTask.invoke(ci, parameters));
    }

    /**
     *  Executes steps returned from the control task
     */
    protected StepExitCode executePlan(List<Step> steps) {
        TestExecutionContext executionContext = new TestExecutionContext(repository);
        try {
            return DeployitTester.executePlan(steps, executionContext);
        } finally {
            executionContext.destroy();
        }
    }

    /**
     * Returns a repository for observation
     */
    public Repository getRepository() {
        return repository;
    }
}

==> test-engine-25.1.0-1127.113-sources.jar: com/xebialabs/deployit/test/task/ControlTaskTester.java <==
package com.xebialabs.deployit.test.task;

import java.util.List;
import java.util.Objects;

import com.xebialabs.deployit.plugin.api.flow.Step;
import com.xebialabs.deployit.plugin.api.flow.StepExitCode;
import com.xebialabs.deployit.plugin.api.reflect.MethodDescriptor;
import com.xebialabs.deployit.plugin.api.services.Repository;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.deployit.plugin.api.udm.Parameters;
import com.xebialabs.deployit.test.deployment.DeployitTester;
import com.xebialabs.deployit.test.repository.InMemoryRepository;
import com.xebialabs.deployit.test.support.TestExecutionContext;

public class ControlTaskTester {

    private final Repository repository;

    public ControlTaskTester() {
        this(new InMemoryRepository());
    }

    public ControlTaskTester(Repository repository) {
        this.repository = repository;
    }

    /**
     * Executes all steps of non-parametrized control task on CI
     */
    @SuppressWarnings("unchecked")
    public StepExitCode executeControlTask(ConfigurationItem ci, String task) {
        MethodDescriptor controlTask = Objects.requireNonNull(ci.getType().getDescriptor().getControlTask(task));
        return executePlan((List<Step>)controlTask.invoke(ci));
    }

    /**
     * Executes all steps of parametrized control task on CI
     */
    @SuppressWarnings("unchecked")
    public StepExitCode executeControlTask(ConfigurationItem ci, String task, Parameters parameters) {
        MethodDescriptor controlTask = Objects.requireNonNull(ci.getType().getDescriptor().getControlTask(task));
        return executePlan((List<Step>) controlTask.invoke(ci, parameters));
    }

    /**
     *  Executes steps returned from the control task
     */
    protected StepExitCode executePlan(List<Step> steps) {
        TestExecutionContext executionContext = new TestExecutionContext(repository);
        try {
            return DeployitTester.executePlan(steps, executionContext);
        } finally {
            executionContext.destroy();
        }
    }

    /**
     * Returns a repository for observation
     */
    public Repository getRepository() {
        return repository;
    }
}
